@@ -37,6 +37,7 @@
 #include "arrow/util/bit_block_counter.h"
 #include "arrow/util/bit_run_reader.h"
 #include "arrow/util/bit_util.h"
+#include "arrow/util/fixed_width_internal.h"
 #include "arrow/util/int_util.h"
 #include "arrow/util/logging.h"
 #include "arrow/util/ree_util.h"
@@ -65,24 +66,6 @@ void RegisterSelectionFunction(const std::string& name, FunctionDoc doc,
   DCHECK_OK(registry->AddFunction(std::move(func)));
 }
 
-Status PreallocatePrimitiveArrayData(KernelContext* ctx, int64_t length, int bit_width,
-                                     bool allocate_validity, ArrayData* out) {
-  // Preallocate memory
-  out->length = length;
-  out->buffers.resize(2);
-
-  if (allocate_validity) {
-    ARROW_ASSIGN_OR_RAISE(out->buffers[0], ctx->AllocateBitmap(length));
-  }
-  if (bit_width == 1) {
-    ARROW_ASSIGN_OR_RAISE(out->buffers[1], ctx->AllocateBitmap(length));
-  } else {
-    ARROW_ASSIGN_OR_RAISE(out->buffers[1],
-                          ctx->Allocate(bit_util::BytesForBits(length * bit_width)));
-  }
-  return Status::OK();
-}
-
 namespace {
 
 /// \brief Iterate over a REE filter, emitting ranges of a plain values array that
@@ -564,39 +547,6 @@ struct VarBinarySelectionImpl : public Selection<VarBinarySelectionImpl<Type>, T
   }
 };
 
-struct FSBSelectionImpl : public Selection<FSBSelectionImpl, FixedSizeBinaryType> {
-  using Base = Selection<FSBSelectionImpl, FixedSizeBinaryType>;
-  LIFT_BASE_MEMBERS();
-
-  TypedBufferBuilder<uint8_t> data_builder;
-
-  FSBSelectionImpl(KernelContext* ctx, const ExecSpan& batch, int64_t output_length,
-                   ExecResult* out)
-      : Base(ctx, batch, output_length, out), data_builder(ctx->memory_pool()) {}
-
-  template <typename Adapter>
-  Status GenerateOutput() {
-    FixedSizeBinaryArray typed_values(this->values.ToArrayData());
-    int32_t value_size = typed_values.byte_width();
-
-    RETURN_NOT_OK(data_builder.Reserve(value_size * output_length));
-    Adapter adapter(this);
-    return adapter.Generate(
-        [&](int64_t index) {
-          auto val = typed_values.GetView(index);
-          data_builder.UnsafeAppend(reinterpret_cast<const uint8_t*>(val.data()),
-                                    value_size);
-          return Status::OK();
-        },
-        [&]() {
-          data_builder.UnsafeAppend(value_size, static_cast<uint8_t>(0x00));
-          return Status::OK();
-        });
-  }
-
-  Status Finish() override { return data_builder.Finish(&out->buffers[1]); }
-};
-
 template <typename Type>
 struct ListSelectionImpl : public Selection<ListSelectionImpl<Type>, Type> {
   using offset_type = typename Type::offset_type;
@@ -662,6 +612,63 @@ struct ListSelectionImpl : public Selection<ListSelectionImpl<Type>, Type> {
   }
 };
 
+template <typename Type>
+struct ListViewSelectionImpl : public Selection<ListViewSelectionImpl<Type>, Type> {
+  using offset_type = typename Type::offset_type;
+
+  using Base = Selection<ListViewSelectionImpl<Type>, Type>;
+  LIFT_BASE_MEMBERS();
+
+  TypedBufferBuilder<offset_type> offsets_builder;
+  TypedBufferBuilder<offset_type> sizes_builder;
+
+  ListViewSelectionImpl(KernelContext* ctx, const ExecSpan& batch, int64_t output_length,
+                        ExecResult* out)
+      : Base(ctx, batch, output_length, out),
+        offsets_builder(ctx->memory_pool()),
+        sizes_builder(ctx->memory_pool()) {}
+
+  template <typename Adapter>
+  Status GenerateOutput() {
+    auto* offsets = this->values.template GetValues<offset_type>(1);
+    auto* sizes = this->values.template GetValues<offset_type>(2);
+
+    offset_type null_list_view_offset = 0;
+    Adapter adapter(this);
+    RETURN_NOT_OK(adapter.Generate(
+        [&](int64_t index) {
+          offset_type value_offset = offsets[index];
+          offset_type value_length = sizes[index];
+          offsets_builder.UnsafeAppend(value_offset);
+          sizes_builder.UnsafeAppend(value_length);
+          null_list_view_offset = value_offset + value_length;
+          return Status::OK();
+        },
+        [&]() {
+          // 0 could be appended here, but by adding the last offset, we keep
+          // the buffer compatible with how offsets behave in ListType as well.
+          // The invariant that `offsets[i] + sizes[i] <= values.length` is
+          // trivially maintained by having `sizes[i]` set to 0 here.
+          offsets_builder.UnsafeAppend(null_list_view_offset);
+          sizes_builder.UnsafeAppend(0);
+          return Status::OK();
+        }));
+    return Status::OK();
+  }
+
+  Status Init() override {
+    RETURN_NOT_OK(offsets_builder.Reserve(output_length));
+    return sizes_builder.Reserve(output_length);
+  }
+
+  Status Finish() override {
+    RETURN_NOT_OK(offsets_builder.Finish(&out->buffers[1]));
+    RETURN_NOT_OK(sizes_builder.Finish(&out->buffers[2]));
+    out->child_data = {this->values.child_data[0].ToArrayData()};
+    return Status::OK();
+  }
+};
+
 struct DenseUnionSelectionImpl
     : public Selection<DenseUnionSelectionImpl, DenseUnionType> {
   using Base = Selection<DenseUnionSelectionImpl, DenseUnionType>;
@@ -908,7 +915,30 @@ Status LargeListFilterExec(KernelContext* ctx, const ExecSpan& batch, ExecResult
   return FilterExec<ListSelectionImpl<LargeListType>>(ctx, batch, out);
 }
 
+Status ListViewFilterExec(KernelContext* ctx, const ExecSpan& batch, ExecResult* out) {
+  return FilterExec<ListViewSelectionImpl<ListViewType>>(ctx, batch, out);
+}
+
+Status LargeListViewFilterExec(KernelContext* ctx, const ExecSpan& batch,
+                               ExecResult* out) {
+  return FilterExec<ListViewSelectionImpl<LargeListViewType>>(ctx, batch, out);
+}
+
 Status FSLFilterExec(KernelContext* ctx, const ExecSpan& batch, ExecResult* out) {
+  const ArraySpan& values = batch[0].array;
+
+  // If a FixedSizeList wraps a fixed-width type we can, in some cases, use
+  // PrimitiveFilterExec for a fixed-size list array.
+  if (util::IsFixedWidthLike(values,
+                             /*force_null_count=*/true,
+                             /*exclude_bool_and_dictionary=*/true)) {
+    const auto byte_width = util::FixedWidthInBytes(*values.type);
+    // 0 is a valid byte width for FixedSizeList, but PrimitiveFilterExec
+    // might not handle it correctly.
+    if (byte_width > 0) {
+      return PrimitiveFilterExec(ctx, batch, out);
+    }
+  }
   return FilterExec<FSLSelectionImpl>(ctx, batch, out);
 }
 
@@ -942,23 +972,6 @@ Status LargeVarBinaryTakeExec(KernelContext* ctx, const ExecSpan& batch,
   return TakeExec<VarBinarySelectionImpl<LargeBinaryType>>(ctx, batch, out);
 }
 
-Status FSBTakeExec(KernelContext* ctx, const ExecSpan& batch, ExecResult* out) {
-  const ArraySpan& values = batch[0].array;
-  const auto byte_width = values.type->byte_width();
-  // Use primitive Take implementation (presumably faster) for some byte widths
-  switch (byte_width) {
-    case 1:
-    case 2:
-    case 4:
-    case 8:
-    case 16:
-    case 32:
-      return PrimitiveTakeExec(ctx, batch, out);
-    default:
-      return TakeExec<FSBSelectionImpl>(ctx, batch, out);
-  }
-}
-
 Status ListTakeExec(KernelContext* ctx, const ExecSpan& batch, ExecResult* out) {
   return TakeExec<ListSelectionImpl<ListType>>(ctx, batch, out);
 }
@@ -967,7 +980,24 @@ Status LargeListTakeExec(KernelContext* ctx, const ExecSpan& batch, ExecResult*
   return TakeExec<ListSelectionImpl<LargeListType>>(ctx, batch, out);
 }
 
+Status ListViewTakeExec(KernelContext* ctx, const ExecSpan& batch, ExecResult* out) {
+  return TakeExec<ListViewSelectionImpl<ListViewType>>(ctx, batch, out);
+}
+
+Status LargeListViewTakeExec(KernelContext* ctx, const ExecSpan& batch, ExecResult* out) {
+  return TakeExec<ListViewSelectionImpl<LargeListViewType>>(ctx, batch, out);
+}
+
 Status FSLTakeExec(KernelContext* ctx, const ExecSpan& batch, ExecResult* out) {
+  const ArraySpan& values = batch[0].array;
+
+  // If a FixedSizeList wraps a fixed-width type we can, in some cases, use
+  // FixedWidthTakeExec for a fixed-size list array.
+  if (util::IsFixedWidthLike(values,
+                             /*force_null_count=*/true,
+                             /*exclude_bool_and_dictionary=*/true)) {
+    return FixedWidthTakeExec(ctx, batch, out);
+  }
   return TakeExec<FSLSelectionImpl>(ctx, batch, out);
 }
 
